@@ -7,7 +7,7 @@ if os.name == "nt":
 import pytest
 
 # Must be set before importing from `jupyter_core`.
-os.environ['JUPYTER_PLATFORM_DIRS'] = '1'
+os.environ["JUPYTER_PLATFORM_DIRS"] = "1"
 
 
 pytest_plugins = ["pytest_jupyter", "pytest_jupyter.jupyter_client"]
